==> jasperreports_3.7.4+dfsg.orig.tar.gz: jasperreports-3.7.4.orig/src/net/sf/jasperreports/engine/JRPrintFrame.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine;

import java.util.List;


/**
 * A print elements container.
 * <p>
 * This is the print result of a {@link net.sf.jasperreports.engine.JRFrame frame} element or a
 * {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab} cell.
 * <p>
 * The coordinates of elements inside a print frame are relative to the frame and not the page.
 * 
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: JRPrintFrame.java 3033 2009-08-27 11:46:22Z teodord $
 */
public interface JRPrintFrame extends JRPrintElement, JRBox, JRBoxContainer
{
	/**
	 * Returns the list of print elements contained in the frame.
	 * 
	 * @return the list of sub print elements
	 */
	public List getElements();
}

==> jasperreports_4.1.3+dfsg.orig.tar.gz: jasperreports-4.1.3.orig/src/net/sf/jasperreports/engine/JRPrintFrame.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine;

import java.util.List;


/**
 * A print elements container.
 * <p>
 * This is the print result of a {@link net.sf.jasperreports.engine.JRFrame frame} element or a
 * {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab} cell.
 * <p>
 * The coordinates of elements inside a print frame are relative to the frame and not the page.
 * 
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: JRPrintFrame.java 4595 2011-09-08 15:55:10Z teodord $
 */
public interface JRPrintFrame extends JRPrintElement, JRBoxContainer
{
	/**
	 * Returns the list of print elements contained in the frame.
	 * 
	 * @return the list of sub print elements
	 */
	public List<JRPrintElement> getElements();
}
